import { httpApp } from "@/plugins/axiosIndex";
import { pickBy } from "lodash-es";
import { object2QueryString } from "@/utils/utils";

// monitor key
export function getUserMonitorKey(recordId) {
  return httpApp.post(
    "/api/admin/monitor/getMonitorKey?" + object2QueryString({ recordId }),
    {}
  );
}

// realtime-monitoring
export function invigilateList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/list?" + object2QueryString(data),
    {}
  );
}
export function invigilateCount(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/exam/list/count?" + object2QueryString(data),
    {}
  );
}
export function invigilateVideoList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/list/video?" + object2QueryString(data),
    {}
  );
}
export function monitorCallCount(examId) {
  return httpApp.post(
    "/api/admin/monitor/call/count?" + object2QueryString({ examId }),
    {}
  );
}

// online-patrol
export function patrolList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/patrol/list?" + object2QueryString(data),
    {}
  );
}

// 强制/手动交卷接口
export function invigilateFinish(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post("/api/admin/invigilate/finish", data);
}
// 结束监考接口
export function invigilateExamFinish(examId) {
  return httpApp.post("/api/admin/invigilate/exam/finish?examId=" + examId, {});
}

// 监考老师::事实监控台-考试批次列表
export function examMonitorBatchList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post("/api/admin/exam/query?" + object2QueryString(data), {});
}
// 监考老师::考试批次列表
export function examBatchList(userId) {
  const paramQuery = userId ? `?userId=${userId}` : "";
  return httpApp.post("/api/admin/sys/exam/query" + paramQuery);
}
// 监考老师::根据权限获取场次和考场接口
export function examActivityRoomList(examId) {
  return httpApp.post("/api/admin/sys/exam/privilegeQuery?examId=" + examId);
}
// 考试属性统计接口
export function examPropCount(examId) {
  return httpApp.post("/api/admin/exam/prop/count?examId=" + examId);
}

export function communicationList({
  examActivityId,
  pageNumber = 1,
  pageSize = 10,
}) {
  const data = pickBy(
    { examActivityId, pageNumber, pageSize },
    (v) => v !== ""
  );
  return httpApp.post(
    "/api/admin/monitor/call/list?" + object2QueryString(data),
    {},
    {
      noErrorMessage: true,
    }
  );
}

export function communicationOver(callCancelBackendMobile) {
  return httpApp.post(
    "/api/admin/monitor/call/cancel",
    { callCancelBackendMobile },
    {
      noErrorMessage: true,
    }
  );
}

// invigilation-detail
export function invigilationHistoryList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/history/list?" + object2QueryString(data),
    {}
  );
}

// waining-manage
export function invigilationWarningList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/warn/list?" + object2QueryString(data),
    {}
  );
}
export function invigilationWarningCount(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/warn/notify?" + object2QueryString(data),
    {}
  );
}
// TODO:批量处理违纪
export function batchInvigilation(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return Promise.resolve(data);
  // return httpApp.post(
  //   "/api/admin/invigilate/warn/list?" + object2QueryString(data),
  //   {}
  // );
}
// TODO:清除未阅
export function clearInvigilationUnreadWarningList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/warn/list?" + object2QueryString(data),
    {}
  );
}

// warning-detail
// 获取当前学生直播视频流
export function warningStudentDetail({ recordId }) {
  const data = {
    recordId,
  };
  return httpApp.post(
    "/api/admin/monitor/call/query?" + object2QueryString(data),
    {}
  );
}
// 获取预警详情信息
export function invigilateDetail(recordId) {
  return httpApp.post(
    "/api/admin/invigilate/list/detail?examRecordId=" + recordId,
    {}
  );
}
// 学生违纪处理
export function updateBreachInfo(datas) {
  const data = pickBy(datas, (v) => v !== "");

  return httpApp.post("/api/admin/invigilate/breach", data);
}

// reexam-apply
export function reexamApplyList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/reexam/list?" + object2QueryString(data),
    {}
  );
}
export function applyReexam(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post("/api/admin/invigilate/reexam/apply", data);
}

// reexam-pending
export function reexamPendingList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/reexam/list_not_done?" + object2QueryString(data),
    {}
  );
}
export function reexamPendingCount(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/reexam/list_not_done_notify?" +
      object2QueryString(data),
    {}
  );
}
export function checkReexamApply(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post("/api/admin/invigilate/reexam/auditing", data);
}

// reexam-checked
export function reexamCheckedList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/reexam/list_done?" + object2QueryString(data),
    {}
  );
}

// progress-detail
export function progressDetailList(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/invigilate/progress/list?" + object2QueryString(data),
    {}
  );
}

// exam-report
// report-overview
// reexam-checked
export function reportOverviewData(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/report/exam_view?" + object2QueryString(data),
    {}
  );
}
// report-statistics
export function reportStatisticsData(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/report/exam_view_count?" + object2QueryString(data),
    {}
  );
}
// report-absent
export function reportAbsentData(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/report/exam_deficiency_list?" + object2QueryString(data),
    {}
  );
}
// report-exception
export function reportExceptionData(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/report/exam_exception_list?" + object2QueryString(data),
    {}
  );
}
export function reportExceptionDetail(datas) {
  // examStudentId
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/report/exam_exception_list_detail?" + object2QueryString(data),
    {}
  );
}
// report-reexam
export function reportReexamData(datas) {
  const data = pickBy(datas, (v) => v !== "");
  return httpApp.post(
    "/api/admin/report/exam_reexam_list?" + object2QueryString(data),
    {}
  );
}
